%define ssl_C  US
%define ssl_O  Fermi National Accelerator Laboratory
%define ssl_OU Scientific Linux
%define ssl_CN Scientific Linux 7 driver update signing key
%define ssl_EMAIL SCIENTIFIC-LINUX-DEVEL@LISTSERV.FNAL.GOV

%define ssl_lifetime 15000

%define ssl_size 3072
%define ssl_keytype rsa:%{ssl_size}

%define ssl_subject /C=%{ssl_C}/O=%{ssl_O}/OU=%{ssl_OU}/CN=%{ssl_CN}/emailAddress=%{ssl_EMAIL}


Name:		kmod-ldup
Version:	0.1.0
Release:	4%{?dist}
Summary:	Provides signing keys for the driver update program
BuildArch:	noarch

Group:		Development/System
License:	GPLv2
URL:		http://www.scientificlinux.org/

BuildRequires:	openssl
Requires:	redhat-release openssl

%description
Drivers packaged with the Linux Driver Update Program require signing keys.
This RPM provides a simple way of deploying these keys.

Storage of the keys in this RPM is your responsibility.


%prep
rm -rf %{_builddir}/%{name}-%{version}
mkdir -p %{_builddir}/%{name}-%{version}

%build
cd %{_builddir}/%{name}-%{version}

cat <<EOF > openssl.cnf
[ req ]
default_bits = %{ssl_size}
distinguished_name = req_distinguished_name
prompt = no
string_mask = utf8only
x509_extensions = kmod_ext

[ req_distinguished_name ]
O = %{ssl_O}
CN = %{ssl_CN}
emailAddress = %{ssl_EMAIL}

[ kmod_ext ]
basicConstraints=critical,CA:FALSE
keyUsage=digitalSignature
subjectKeyIdentifier=hash
authorityKeyIdentifier=keyid
EOF


openssl req -config openssl.cnf -x509 -utf8 -sha256 -nodes -batch -outform der -newkey %{ssl_keytype} -keyout signing_key.priv -out signing_key.x509 -days %{ssl_lifetime} -subj '%{ssl_subject}' -extensions kmod_ext


%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_usrsrc}/%{name}

cd %{_builddir}/%{name}-%{version}
%{__install} signing_key.priv %{buildroot}%{_usrsrc}/%{name}/signing_key.priv
%{__install} signing_key.x509 %{buildroot}%{_usrsrc}/%{name}/signing_key.x509

%check
cat %{buildroot}%{_usrsrc}/%{name}/signing_key.x509 | openssl x509 -inform der -text

%triggerin -- kernel-devel
for ver in $(cd %{_usrsrc}/kernels ; ls); do
  cd %{_usrsrc}/kernels/${ver}
  if [[ ! -e signing_key.priv ]]; then
    ln -s %{_usrsrc}/%{name}/signing_key.priv .
  fi
  if [[ ! -e signing_key.x509 ]]; then
    ln -s %{_usrsrc}/%{name}/signing_key.x509 .
  fi
done

%files
%defattr(0644,root,root,0755)
%doc
%{_usrsrc}/%{name}/signing_key.priv
%{_usrsrc}/%{name}/signing_key.x509

%changelog
* Thu Jan 11 2018 Pat Riehecky - 0.1.0-4
- Switch to sha256 from sha512

* Wed Jan 10 2018 Pat Riehecky - 0.1.0-3
- remove issue id as it is self signed

* Fri Jul 28 2017 Pat Riehecky - 0.1.0-2
- fix openssl.cnf

* Fri Jul 28 2017 Pat Riehecky - 0.1.0
- Initial build for el7.

